chevron <- 
structure(.Data = list(structure(.Data = c(1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2)
, levels = c("data", "noise")
, class = "factor"
)
, c(54.234892748296261, 48.235562283080071, 55.687680731993169, 
	42.526220000814646, 57.036088942084461, 38.920804302673787, 
	50.352763144299388, 22.635154556017369, 45.188236500136554, 
	50.147577424999326, 62.931766451802105, 47.640057321172208, 
	32.879657312761992, 24.837501123547554, 86.163869962561876, 
	86.837749335449189, 30.155830167233944, 85.877189304679632, 
	52.519144220743328, 57.793714497238398, 43.241628542076796, 
	36.721126145217568, 76.442784171551466, 64.163636977784336, 
	39.956034869886935, 69.729254734702408, 56.731933660805225, 
	47.354641291312873, 96.121449000202119, 82.79412979632616, 
	27.851137142628431, 24.93720111111179, 70.782046268228441, 
	48.560211469419301, 93.043078976683319, 32.209129346068949, 
	51.966823963914067, 86.239495593588799, 66.112952909898013, 
	58.24884533463046, 58.838225212879479, 56.636853196658194, 
	28.494492165744305, 57.653920940123498, 58.695394218433648, 
	86.625092410948128, 79.084716598968953, 78.508364506531507, 
	67.891362857073545, 73.143478830344975, 53.011723873205483, 
	30.373510002158582, 73.353310863021761, 29.196813782211393, 
	47.826015655882657, 95.469707596115768, 66.416002587880939, 
	36.85956151643768, 83.042443388141692, 54.88353905454278, 
	20.405374596826732, 56.198116395156831, 88.915851167403162, 
	59.562612885143608, 24.462514431215823, 31.448000574950129, 
	84.677187889814377, 87.364191023632884, 42.840826678089797, 
	92.397713405545801, 34.250688253901899, 69.683547101449221, 
	63.546513228211552, 43.672808268573135, 41.922648540697992, 
	56.473112017847598, 23.171860761009157, 49.953823303803802, 
	46.436614512931556, 38.59219811623916, 36.842365437187254, 
	26.409177205059677, 37.328651405405253, 34.927986776456237, 
	23.656566813588142, 54.236644501797855, 52.210703836753964, 
	28.157244871836156, 40.096746440976858, 31.42181457253173, 
	39.851036574691534, 31.424492257647216, 21.042729932814837, 
	29.523033264558762, 15.452032738830894, 30.015379111282527, 
	17.606630416121334, 57.101884072180837, 20.443842625245452, 
	28.15221022348851, 49.629977764561772, 51.881898459978402, 
	57.992464969865978, 41.258769547566772, 43.240769172552973, 
	29.272754858247936, 22.174956740345806, 15.878613241948187, 
	47.602522533852607, 15.149760278873146, 29.244020255282521, 
	10.318592390976846, 15.792438546195626, 58.153129788115621, 
	20.091362772509456, 17.016000929288566, 55.212599416263402, 
	34.973146319389343, 53.71798048261553, 42.072467103134841, 
	33.85334680788219, 42.941173664294183, 30.652374024502933, 
	24.599534531589597, 58.054738822393119, 49.216255359351635, 
	58.694438498932868, 33.398411432281137, 33.487216115463525, 
	56.60395851591602, 40.388811649754643, 45.681617558002472, 
	44.670640942640603, 47.806818750686944, 63.221794744022191, 
	21.259777629747987, 46.282551544718444, 28.109394870698452, 
	39.038281014654785, 26.695298594422638, 52.581904833205044, 
	38.105826680548489, 53.261818196624517, 22.38856595242396, 
	34.513444658368826, 52.018882452975959, 46.146133805159479, 
	27.751676877960563, 22.251768377609551, 23.039224445819855, 
	27.827243870124221, 47.182311916258186, 33.193872570991516, 
	33.675142102874815, 47.399089089594781, 29.215442202985287, 
	19.19504533521831, 39.283584766089916, 45.919479306321591, 
	24.246974098496139, 40.75248803012073, 18.43075955985114, 
	38.122169103007764, 18.892768386285752, 33.499488248489797, 
	28.507504318840802, 46.171165551058948, 55.270138657651842, 
	53.00451789284125, 26.972963795997202, 59.249994799029082, 
	21.945157558657229, 56.327855265699327, 40.006134547293186, 
	37.262823963537812, 25.617648903280497, 55.879329103045166, 
	24.799662989098579, 40.955960997380316, 43.778304925654083, 
	29.831844971049577, 56.157954586669803, 64.189819009043276, 
	39.882790127303451, 43.470695824362338, 41.053441364783794, 
	19.858526606112719, 27.550494831521064, 60.940338368527591, 
	55.592591632157564, 47.432575717102736, 38.313838448375463, 
	63.655514353886247, 23.842276630457491, 55.173727651126683, 
	36.56159303849563, 51.171865740325302, 14.076206854078919, 
	28.135600308887661, 40.992705882526934, 33.077532607130706, 
	27.613630839623511, 31.261784746311605, 54.491466227918863, 
	17.863415980245918, 45.307226125150919, 14.00991789996624, 
	47.494816437829286, 30.550595805980265, 22.459614060353488, 
	25.26177371153608, 38.942916460800916, 53.661402179859579, 
	56.124480329453945, 60.420438817236573, 74.254679393488914, 
	74.963943171314895, 76.253521561156958, 72.367728634271771, 
	73.941699247807264, 84.805357372388244, 46.228766483254731, 
	65.132539374753833, 86.463511495385319, 60.991641394793987, 
	71.728394830133766, 64.568556053563952, 70.021648365072906, 
	96.391001576557755, 78.706610652152449, 86.667805800680071, 
	71.702183936722577, 84.603021314833313, 59.024730327073485, 
	86.668122820556164, 82.75913733523339, 56.638916553929448, 
	51.76590992603451, 60.289750411175191, 70.936234463006258, 
	69.140980679076165, 82.953922473825514, 94.843533814419061, 
	95.314143276773393, 55.126623443793505, 92.814025529660285, 
	74.851102968677878, 89.899483653716743, 89.917693706229329, 
	56.741508990526199, 83.786134459078312, 96.84357285965234, 
	47.818922619335353, 73.453598842024803, 60.395266306586564, 
	74.826042328495532, 78.906501308083534, 60.655096885748208, 
	73.928653816692531, 79.443247432354838, 49.473912711255252, 
	60.718888929113746, 59.773725408595055, 67.382725598290563, 
	86.062307746615261, 59.336203166749328, 66.709851818159223, 
	64.263534042984247, 58.793802275322378, 68.099827175028622, 
	55.757865277118981, 91.672143219038844, 66.455129287205637, 
	79.538362873718143, 62.841279662679881, 78.063955535180867, 
	59.176526232622564, 70.252592810429633, 64.215119602158666, 
	92.512990746181458, 77.417090851813555, 61.613753747660667, 
	62.781374778132886, 84.352812813594937, 97.196518606506288, 
	87.331147640943527, 75.889226933941245, 60.499696799088269, 
	74.571702843531966, 70.27152115944773, 65.689407796598971, 
	76.708736689761281, 95.170646188780665, 63.154367236420512, 
	63.813885564450175, 95.110226231627166, 69.104425115510821, 
	86.728514351416379, 62.054581318516284, 94.769142719451338, 
	79.102635909803212, 87.765462999232113, 54.075649841688573, 
	55.873192274011672, 61.642944214399904, 88.682003612630069, 
	53.23315066518262, 82.474950519390404, 60.009071207605302, 
	77.290643295273185, 69.260751297697425, 74.735402576625347, 
	63.513273554854095, 86.321564957033843, 75.078163505531847, 
	58.225159978028387, 73.75684337457642, 61.371734300628304, 
	54.869736698456109, 69.747709559742361, 67.061143447645009, 
	78.089036212768406, 98.98887749761343, 79.364319217856973, 
	54.671592689119279, 55.085043162107468, 57.299722910393029, 
	77.168781748041511, 55.688775470480323, 85.181349173653871, 
	56.649081571958959, 79.601930344942957, 50.526558889541775, 
	87.531525117810816, 79.453271641395986, 64.015951626934111, 
	70.957273826934397, 73.659181636758149, 71.422531078569591, 
	52.113710390403867, 97.270094121340662, 60.998607259243727, 
	86.876463498920202, 68.728787831496447, 70.580466347746551, 
	82.039276428986341, 88.508475383277982, 62.857153776567429, 
	52.871364126913249, 18.260733188129961, 48.242243095766753, 
	104.85621612565592, 1.6468111644499004, 76.292511423118412, 
	82.846835286356509, 115.03907246515155, 8.4224839634262025, 
	110.26245710160583, 94.396102156490088, 98.428357252851129, 
	124.09517906373367, 2.5983997522853315, 28.010582229122519, 
	119.88305351790041, 37.371480740141124, 39.761460340116173, 
	120.57179889362305, 116.0976435332559, 12.473358022514731, 
	100.81065120967105, 23.259111578576267, 57.104839666280895, 
	41.63804620411247, 125.79464095178992, 126.63052967749536, 
	51.325166821014136, 105.67170533211902, 77.81598101882264, 
	15.22361704101786, 16.829490541480482, 116.5133208623156, 
	69.092953691259027, 100.55104284081608, 84.581971760839224, 
	125.43950975919142, 15.455725486855954, 49.709088711533695, 
	54.316982565913349, 98.122927467338741, 25.547892076894641, 
	54.029593718703836, 99.194448021240532, 95.67859789961949, 
	53.914788392838091, 12.175311088562012, 36.264842866454273, 
	126.89444229984656, 109.88714680075645, 3.6363264066167176, 
	61.86572879133746, 9.9464483158662915, 111.91885753022507, 
	102.0582111896947, 49.773802845273167, 33.060074502136558, 
	34.408025745302439, 8.7543834708631039, 6.7590066683478653, 
	118.4957725442946, 7.5494405799545348, 21.147015653550625, 
	13.96845042752102, 89.82311094738543, 96.392688883468509, 
	100.12316969316453, 68.562505691777915, 33.892352260649204, 
	42.616237458307296, 124.94237693725154, 51.896007396746427, 
	6.1892119063995779, 21.306909190956503, 100.04009515233338, 
	50.746443669311702, 62.667456711176783, 4.1698864176869392, 
	60.298391849268228, 26.091923768632114, 23.167692231480032, 
	116.79595653200522, 87.406535304617137, 102.55936067225412, 
	87.005080546252429, 71.44628586852923, 36.024712040089071, 
	114.48299978068098, 119.21788525814191, 6.5931212874129415, 
	73.500397203024477, 124.14050844404846, 17.019308641087264, 
	9.7509031379595399, 93.795005307998508, 88.002286639530212, 
	3.4815936917439103, 62.028843510895967, 5.9062781170941889, 
	112.7428733361885, 74.688497961964458, 124.67752790823579, 
	103.71663541346788, 114.77148305391893, 122.43437082925811, 
	58.048309536185116, 48.08694654982537, 23.48470267187804, 
	86.648323563858867, 104.64580322988331, 85.281665418297052, 
	2.5967782204970717, 122.72191030345857, 37.825218854472041, 
	73.602769385557622, 106.07903028512374, 80.29449285985902, 
	64.573924379888922, 3.7934052241034806, 14.411271899472922, 
	9.1130882548168302, 121.82028404390439, 64.086428255308419, 
	30.142027483321726, 9.2218365068547428, 57.943212111014873, 
	88.525624772999436, 73.029497192241251, 39.642025673761964, 
	47.75100915087387, 59.43292783619836, 86.025916869752109, 
	106.87721258634701, 74.76745021995157, 50.658329186029732, 
	99.179475331678987, 80.779239672236145, 31.022781821433455, 
	27.701226088218391, 70.397150602657348, 59.157695125322789, 
	52.216560912784189, 15.965767580084503, 4.5535093531943858, 
	40.315483149141073, 119.72016133833677, 70.820953687187284, 
	55.254787453450263, 107.04329040553421, 58.29693005932495, 
	60.950731799006462, 94.778017394710332, 16.855303465854377, 
	5.1008030329830945, 125.20530501380563, 19.123279816005379, 
	117.05310684815049, 30.921934833284467, 15.594612206798047, 
	36.559576065745205, 73.97708597406745, 9.1608772254548967, 
	60.407161391340196, 30.619238510727882, 39.713751916773617, 
	96.817864642944187, 86.451950440183282, 63.908302642405033, 
	8.8742578355595469, 60.937965170945972, 38.38533392501995, 
	70.242368211038411, 127.44251992600039, 97.17243448831141, 
	113.34552459372208, 45.340859668329358, 47.084083457943052, 
	123.78408719366416, 79.461673388257623, 76.060394993517548, 
	83.992182818241417, 100.19052438251674, 85.134706522803754, 
	32.949363013263792, 56.675030249170959, 4.1729824617505074, 
	82.929926445242018, 54.178752406965941, 111.72389138210565, 
	61.557107215747237, 100.60162192955613, 89.411813451442868, 
	1.5963736544363201, 77.989755954127759, 37.082840334624052, 
	122.86444625351578, 99.470816673710942, 73.503071467857808, 
	77.225126214325428, 6.604564858134836, 89.609252910129726, 
	78.241926767863333, 40.839448155835271, 68.662037074100226, 
	3.8544323379173875, 23.432667226530612, 119.54267649631947, 
	74.391020122449845, 66.262053582817316, 19.436904431320727, 
	98.661847421899438, 121.38916345639154, 3.3399431114085019, 
	19.744615266565233, 11.624164030887187, 25.567141579464078, 
	56.174077581148595, 77.977524415589869, 46.894562827423215, 
	67.996121652424335, 110.04782931134105, 123.87353478791192, 
	86.362637150567025, 26.791294113267213, 71.1956223892048, 
	1.7693870570510626, 8.8763646027073264, 113.83987859310582, 
	8.1820756569504738, 4.6885575391352177, 77.906489034183323, 
	15.124028530437499, 16.82679202966392, 41.167970235925168, 
	39.351054778322577, 92.120821432210505, 68.75347268441692, 
	84.129290046170354, 123.46324638044462, 11.986010336782783, 
	36.466133574023843, 63.905688048806041, 47.197478673886508, 
	65.146065894979984, 104.04342418909073, 51.899855570401996, 
	88.870257258415222, 16.011577168945223, 68.754992792848498, 
	93.34779418585822, 28.541898921132088, 98.468859472777694, 
	41.606486862991005, 62.116508715320379, 30.079980872571468, 
	14.848973709624261, 53.583268321119249, 51.051180050242692, 
	98.171318827662617, 96.896620204672217, 111.75066561065614, 
	121.21503516566008, 62.102458298206329, 117.31530580017716, 
	95.633917333092541, 81.658740204758942, 59.490287091117352, 
	118.55465504201129, 75.581577219069004, 6.9790993737988174, 
	55.863192815799266, 47.785586945712566, 44.529544668737799, 
	45.547190791461617, 35.004935494624078, 61.310466902330518, 
	26.708701082039624, 25.201865449082106, 19.590230466332287, 
	109.16138148587197, 19.669482204131782, 57.935748239047825, 
	39.934332637116313, 61.158326249103993, 93.898421884980053, 
	25.0810880321078, 1.1837924285791814, 78.590424932073802, 
	21.96231254003942, 113.68255837028846, 69.974941077176481, 
	120.12450284790248, 81.634451469406486, 5.2411539158783853, 
	110.4009982724674, 95.545921482611448, 117.5203898595646, 
	97.689060288015753, 23.467674252111465, 2.748198501765728, 
	6.6315603847615421, 71.713750023394823, 71.053446122445166, 
	60.598172856494784, 123.81770013598725, 5.4371770550496876, 
	104.46403920929879, 84.399017982184887, 95.456913054455072, 
	80.965890228748322, 109.38921471545473, 26.762251431588084, 
	37.649710851255804, 121.72102635679767, 126.67810095753521, 
	43.483440926298499, 121.78167054569349, 29.73739477340132, 
	88.853728622198105, 95.963571037631482, 36.41423639561981, 
	104.0495452512987, 78.288063809275627, 19.371748292818666, 
	1.5300123225897551, 8.3644131482578814, 104.9899572217837, 
	94.865336695220321, 72.51575589645654, 4.1911874515935779, 
	64.119399007409811, 13.819417232181877, 103.48210836062208, 
	68.552552068606019, 95.352681246586144, 81.033778943121433, 
	109.84260302269831, 15.163799851667136, 19.409917893819511, 
	1.6820975034497678, 86.994094415567815, 59.279218757990748, 
	123.63031288515776, 110.5170444524847, 2.6766205793246627, 
	12.684948138892651, 75.433121575042605, 122.52482425933704, 
	106.65533459326252, 111.56037309812382, 84.331093725282699, 
	102.10965347103775, 117.70885698823258, 20.62237522052601, 
	34.097953490447253, 101.26351714227349, 103.69528239639476, 
	37.422555768396705, 72.108009223360568, 121.90218550385907, 
	35.984306571539491, 15.215452017262578, 51.837688966654241, 
	103.8142516980879, 11.267733495682478, 123.40852295001969, 
	127.43777437740937, 37.49273966671899, 6.8147043543867767, 
	34.755856880918145, 69.906424306798726, 42.680059125646949, 
	36.846497123595327, 34.352577625773847, 67.987395754549652, 
	3.5804628948681056, 97.458876638673246, 62.403605297673494, 
	24.263261712156236, 53.560122328344733, 52.885797698050737, 
	111.79160557733849, 72.723893656395376, 54.686022360343486, 
	107.16449734894559, 55.267980591859668, 124.39840580383316, 
	45.689928760286421, 65.10774543043226, 78.407875664066523, 
	96.507699007634073, 125.61199676571414, 40.713500986341387, 
	117.64885599492118, 45.13085891213268, 39.144257285166532, 
	51.140286944806576, 68.564957298338413, 28.072209012228996, 
	33.947671634610742, 67.218429885338992, 100.59878586046398, 
	71.113587689120322, 76.079066116828471, 35.112949891015887, 
	116.12001450965181, 13.554063984192908, 41.743181419093162, 
	109.03411462996155, 93.742289054673165, 51.076567114796489, 
	63.012148394715041, 14.186432403512299, 121.90845459094271, 
	4.7878580428659916, 25.204745103605092, 126.70518590230495, 
	94.604904875159264, 15.336439732462168, 34.994519759435207, 
	54.699474409222603, 2.1904001417569816, 111.89486372098327, 
	23.308798969723284, 25.591879297979176, 57.072093228343874, 
	45.181771958712488, 22.431650512851775, 14.472638057079166, 
	21.756868501659483, 1.7477369848638773, 46.290041595231742, 
	112.94135494204238, 25.64110055565834, 44.971031255554408, 
	67.092865049373358, 10.63843137351796, 42.277234117034823, 
	48.672111710999161, 116.27852579159662, 110.81964662577957, 
	41.385295828338712, 38.072848681360483, 51.678193079773337, 
	36.094593974761665, 115.86631702305749, 18.309762539807707, 
	68.309295037295669, 89.182596073951572, 74.504600916523486, 
	17.972932083066553, 15.980133503675461, 126.9110757894814, 
	16.171689165756106, 117.12328152079135, 27.26665338082239, 
	53.044957084115595, 4.617964044213295, 101.03790410840884, 
	44.606407842133194, 88.691944470629096, 6.4330017799511552, 
	41.898747816216201, 47.175609255209565, 126.01479918323457, 
	66.758705249987543, 58.376265360508114, 11.086736034601927, 
	11.030157355125993, 41.216917916666716, 121.85634823795408, 
	6.8825527359731495, 65.465182333718985, 83.111177435144782, 
	52.452948359772563, 9.1498894388787448, 14.269479030743241, 
	47.595099097117782, 112.13049998460338, 116.07430108077824, 
	6.0370199205353856, 38.151698983740062, 92.737055672332644, 
	120.86318689631298, 57.287359778769314, 118.79266786482185, 
	49.239546886645257, 118.0956919984892, 114.77072282228619, 
	24.904520731419325, 99.054818219970912, 110.38396541727707, 
	95.475155420135707, 32.069896012544632, 13.677838505711406, 
	83.00076205516234, 70.97665379755199, 55.328131975606084, 
	7.9869723655283451, 11.523691274225712, 31.495840937364846, 
	20.604578053113073, 125.19503529276699, 47.596286844462156, 
	76.019509848672897, 48.157864126376808, 116.5377921005711, 
	49.164441619534045, 47.285962361842394, 84.865094321779907, 
	109.33376204222441, 14.316439345944673, 108.73915001982823, 
	44.551680212840438, 121.51971181621775, 87.250408151652664, 
	121.70577121945098, 47.787018937058747, 123.2182313837111, 
	35.028488304466009, 47.08707742812112, 60.103482178878039, 
	100.84473324241117, 96.709089009556919, 76.630582911428064, 
	77.592385038267821, 122.52542410604656, 72.508548037149012, 
	102.56203067908064, 46.310730540659279, 22.537071191705763, 
	4.1330515244044363, 102.90699747717008, 69.452451351564378, 
	14.738065110519528, 29.667451511602849, 35.88278167322278, 
	34.731176704633981, 7.5309895719401538, 86.908354658167809, 
	11.805155282374471, 82.665265182498842, 32.997436915524304, 
	53.888008841779083, 83.23318748595193, 69.892676030751318, 
	90.730076037812978, 37.473621216136962, 127.20602490520105, 
	29.535287474747747, 109.34459417499602, 7.859430986456573, 
	104.13339983532205, 93.895296862814575, 35.378559447359294, 
	17.274222793988883, 112.83955960115418, 79.045637499541044, 
	59.226491859648377, 100.95573297468945, 102.18857787456363, 
	116.51885751308873, 107.04330383008346, 74.539201479870826, 
	114.01300944574177, 127.49163325503469, 86.395918145775795, 
	56.897064783144742, 12.838676023297012, 6.8202548436820507, 
	11.682935288175941, 93.948530109133571, 61.740293410606682, 
	3.0686158798635006, 59.252136829309165, 62.359675263985991, 
	125.81377933220938, 68.792252954561263, 99.920908810570836, 
	85.574392623268068, 117.45267974492162, 80.532076333649457, 
	67.656891335733235, 27.311675179284066, 50.9422103818506, 
	76.833226186688989, 15.926986836828291, 25.256496267858893, 
	1.6712627685628831, 37.518133236560971, 90.936042805667967, 
	47.754298283718526, 99.053256300278008, 68.140343063510954, 
	100.42655545799062, 43.250397020019591, 53.686695897951722, 
	54.387864126823843, 113.96069220313802, 39.537609825376421, 
	35.504880375228822, 46.30884944787249, 17.218782066833228, 
	61.886631110217422, 104.71265198523179, 45.434518727008253, 
	29.029845034237951, 88.705212538130581, 103.89363685343415, 
	111.74549112701789, 85.929819569922984, 78.448190472554415, 
	112.35312785999849, 105.10448920726776, 71.397151604294777, 
	121.96557190828025, 56.93980978988111, 25.294881371315569, 
	3.6926564066670835, 34.967766820918769, 103.30494464328513, 
	77.03356321901083, 76.635911806952208, 72.96371441707015, 
	27.069402043242007, 10.617021760437638, 70.410816557239741, 
	113.8048245520331, 10.498747933190316, 126.10665698675439, 
	119.87614507926628, 76.764509881380945, 45.719567503780127, 
	18.124324036762118, 42.609524000901729, 29.660280318465084, 
	125.27662083227187, 123.40803913399577, 68.861474188510329, 
	27.371462917421013, 119.41296566277742, 21.388890074566007, 
	7.3319276352412999, 123.09525157185271, 91.953839023131877, 
	39.443951417226344, 125.84959058882669, 120.18227855954319, 
	38.929774562828243, 98.623340787831694, 69.045814539771527, 
	47.660000819712877, 53.13523676386103, 13.191091790329665, 
	122.00679414533079, 112.7695490391925, 45.675307001452893, 
	73.082477146293968, 79.783281884621829, 99.721362643875182, 
	8.3743955129757524, 49.882082361727953, 111.73017028626055, 
	66.770922181196511, 73.236168541945517, 7.1926889792084694, 
	48.820143505930901, 121.72270194161683, 8.7430376568809152, 
	101.28646525600925, 24.302910142578185, 89.778497385326773, 
	35.051496089436114, 63.365828080102801, 108.21273630438372, 
	65.046511330176145, 107.93921152735129, 22.546639879234135, 
	71.300482785329223, 45.963531245943159, 121.55102502088994, 
	26.931785392109305, 57.460004154127091, 29.97740755835548, 
	67.428827523253858, 126.03811366297305, 111.33692224463448, 
	33.805739079602063, 73.186330228112638, 95.211517202667892, 
	41.343767133075744, 18.037236738484353, 35.619029317516834, 
	95.217294844798744, 86.480003785807639, 110.24814067734405, 
	20.788849980570376, 97.057657016906887, 117.95269003324211, 
	11.816918676719069, 96.746365848463029, 43.315061063040048, 
	57.50252029299736, 15.764123576227576, 84.346445022616535, 
	95.762169148772955, 37.572667067404836, 41.099415498320013, 
	2.5994864902459085, 15.284549473319203, 1.6876453314907849, 
	7.6129189454950392, 3.1049187588505447, 47.758530328515917, 
	80.731851249933243, 125.15207892330363, 52.50024718651548, 
	109.18804352777079, 68.070850263349712, 119.50526943337172, 
	69.075300113297999, 118.62118628015742, 100.21520160185173, 
	108.88847565744072, 86.729670181870461, 64.036794798914343, 
	61.030501062050462, 90.623023596126586, 17.425544608850032, 
	85.020715777296573, 13.209796918556094, 19.354592605959624, 
	115.24600189737976, 64.559205160010606, 27.832398009486496, 
	4.8956242920830846, 19.512852606363595, 73.795337684452534, 
	45.51142584066838, 25.107413691468537, 74.064806059468538, 
	68.486655332613736, 50.806855205446482, 64.279663819354028, 
	112.59897831315175, 110.95997669175267, 1.4558871067129076, 
	16.062978762667626, 67.404507799074054, 76.246016886550933, 
	118.46167040430009, 73.428288508206606, 80.329179943539202, 
	57.935969418846071, 82.847283323295414, 58.561363932676613)
, c(36.597284914925694, 40.698521614074707, 50.629234757740051, 
	37.862097983714193, 39.875036876183003, 32.654850579798222, 
	52.743632549419999, 19.151394074782729, 33.131827239412814, 
	49.661798519082367, 50.189789352938533, 33.444164694752544, 
	15.609109182376415, 19.741804568096995, 14.192305614240468, 
	20.925381786189973, 28.668452797457576, 15.127970912493765, 
	53.624140632804483, 44.274768250528723, 34.713419219478965, 
	24.449981816112995, 35.270084713120013, 47.488972298800945, 
	38.275700125843287, 45.098942134995013, 54.668989978265017, 
	44.501173805911094, 23.196823325939476, 25.374713617376983, 
	12.261850818991661, 5.8538755369372666, 40.726678393781185, 
	52.831362747587264, 16.877141304314137, 23.788769717793912, 
	40.814581041224301, 27.046392838936299, 46.253369156736881, 
	61.208049123641104, 55.82941138651222, 40.56769672036171, 
	9.4526651259511709, 61.886471257545054, 41.35168637521565, 
	17.617923899553716, 29.457988624460995, 36.676529378630221, 
	46.932702858932316, 32.006159091368318, 42.240199570544064, 
	19.164341490715742, 38.592847236432135, 28.566003083717078, 
	38.204341431614012, 19.854599759913981, 35.622397341765463, 
	28.054100892040879, 31.422245074529201, 62.222894483245909, 
	16.682205139659345, 41.318396627437323, 11.22821647208184, 
	41.668097087182105, 14.231764977332205, 22.588176617398858, 
	19.057407031301409, 25.257744455244392, 37.717769826762378, 
	17.011566579341888, 22.600028838496655, 41.415341802872717, 
	47.879320282954723, 37.787089704535902, 39.556233814917505, 
	47.577056798618287, 6.8728428245522082, 43.875519670546055, 
	39.579561182763427, 25.745320606511086, 25.036056828685105, 
	23.746478438843042, 27.632271365728229, 26.058300752192736, 
	15.194642627611756, 53.771233516745269, 34.867460625246167, 
	13.536488504614681, 39.008358605206013, 28.271605169866234, 
	35.431443946436048, 29.978351634927094, 3.6089984234422445, 
	21.293389347847551, 13.332194199319929, 28.297816063277423, 
	15.396978685166687, 40.975269672926515, 13.331877179443836, 
	17.24086266476661, 43.361083446070552, 48.23409007396549, 
	39.710249588824809, 29.063765536993742, 30.859019320923835, 
	17.046077526174486, 5.1564661855809391, 4.6858567232266068, 
	44.873376556206495, 7.1859744703397155, 25.148897031322122, 
	10.100516346283257, 10.082306293770671, 43.258491009473801, 
	16.213865540921688, 3.1564271403476596, 52.181077380664647, 
	26.546401157975197, 39.604733693413436, 25.173957671504468, 
	21.093498691916466, 39.344903114251792, 26.071346183307469, 
	20.556752567645162, 50.526087288744748, 39.281111070886254, 
	40.226274591404945, 32.617274401709437, 13.937692253384739, 
	40.663796833250672, 33.290148181840777, 35.736465957015753, 
	41.206197724677622, 31.900172824971378, 44.242134722881019, 
	8.3278567809611559, 33.544870712794363, 20.461637126281857, 
	37.158720337320119, 21.936044464819133, 40.823473767377436, 
	29.747407189570367, 35.784880397841334, 7.4870092538185418, 
	22.582909148186445, 38.386246252339333, 37.218625221867114, 
	15.647187186405063, 2.8034813934937119, 12.668852359056473, 
	24.110773066058755, 39.500303200911731, 25.428297156468034, 
	29.72847884055227, 34.310592203401029, 23.291263310238719, 
	4.8293538112193346, 36.845632763579488, 36.186114435549825, 
	4.8897737683728337, 30.895574884489179, 13.271485648583621, 
	37.945418681483716, 5.2308572805486619, 20.897364090196788, 
	12.234537000767887, 45.924350158311427, 44.126807725988328, 
	38.357055785600096, 11.317996387369931, 46.76684933481738, 
	17.525049480609596, 39.990928792394698, 22.709356704726815, 
	30.739248702302575, 25.264597423374653, 36.486726445145905, 
	13.678435042966157, 24.921836494468153, 41.774840021971613, 
	26.24315662542358, 38.628265699371696, 45.130263301543891, 
	30.252290440257639, 32.938856552354991, 21.910963787231594, 
	1.01112250238657, 20.635680782143027, 45.328407310880721, 
	44.914956837892532, 42.700277089606971, 22.831218251958489, 
	44.311224529519677, 14.818650826346129, 43.350918428041041, 
	20.398069655057043, 49.473441110458225, 12.468474882189184, 
	20.546728358604014, 35.984048373065889, 29.042726173065603, 
	26.340818363241851, 28.577468921430409, 47.886289609596133, 
	2.7299058786593378, 39.001392740756273, 13.123536501079798, 
	31.271212168503553, 29.419533652253449, 17.960723571013659, 
	11.491524616722018, 37.142846223432571, 47.128635873086751, 
	49.953823303803802, 46.436614512931556, 38.59219811623916, 
	36.842365437187254, 26.409177205059677, 37.328651405405253, 
	34.927986776456237, 23.656566813588142, 54.236644501797855, 
	52.210703836753964, 28.157244871836156, 40.096746440976858, 
	31.42181457253173, 39.851036574691534, 31.424492257647216, 
	21.042729932814837, 29.523033264558762, 15.452032738830894, 
	30.015379111282527, 17.606630416121334, 57.101884072180837, 
	20.443842625245452, 28.15221022348851, 49.629977764561772, 
	51.881898459978402, 57.992464969865978, 41.258769547566772, 
	43.240769172552973, 29.272754858247936, 22.174956740345806, 
	15.878613241948187, 47.602522533852607, 15.149760278873146, 
	29.244020255282521, 10.318592390976846, 15.792438546195626, 
	58.153129788115621, 20.091362772509456, 17.016000929288566, 
	55.212599416263402, 34.973146319389343, 53.71798048261553, 
	42.072467103134841, 33.85334680788219, 42.941173664294183, 
	30.652374024502933, 24.599534531589597, 58.054738822393119, 
	49.216255359351635, 58.694438498932868, 33.398411432281137, 
	33.487216115463525, 56.60395851591602, 40.388811649754643, 
	45.681617558002472, 44.670640942640603, 47.806818750686944, 
	63.221794744022191, 21.259777629747987, 46.282551544718444, 
	28.109394870698452, 39.038281014654785, 26.695298594422638, 
	52.581904833205044, 38.105826680548489, 53.261818196624517, 
	22.38856595242396, 34.513444658368826, 52.018882452975959, 
	46.146133805159479, 27.751676877960563, 22.251768377609551, 
	23.039224445819855, 27.827243870124221, 47.182311916258186, 
	33.193872570991516, 33.675142102874815, 47.399089089594781, 
	29.215442202985287, 19.19504533521831, 39.283584766089916, 
	45.919479306321591, 24.246974098496139, 40.75248803012073, 
	18.43075955985114, 38.122169103007764, 18.892768386285752, 
	33.499488248489797, 28.507504318840802, 46.171165551058948, 
	55.270138657651842, 53.00451789284125, 26.972963795997202, 
	59.249994799029082, 21.945157558657229, 56.327855265699327, 
	40.006134547293186, 37.262823963537812, 25.617648903280497, 
	55.879329103045166, 24.799662989098579, 40.955960997380316, 
	43.778304925654083, 29.831844971049577, 56.157954586669803, 
	64.189819009043276, 39.882790127303451, 43.470695824362338, 
	41.053441364783794, 19.858526606112719, 27.550494831521064, 
	60.940338368527591, 55.592591632157564, 47.432575717102736, 
	38.313838448375463, 63.655514353886247, 23.842276630457491, 
	55.173727651126683, 36.56159303849563, 51.171865740325302, 
	14.076206854078919, 28.135600308887661, 40.992705882526934, 
	33.077532607130706, 27.613630839623511, 31.261784746311605, 
	54.491466227918863, 17.863415980245918, 45.307226125150919, 
	14.00991789996624, 47.494816437829286, 30.550595805980265, 
	22.459614060353488, 25.26177371153608, 38.942916460800916, 
	53.661402179859579, 1.1891810544766486, 13.974514538887888, 
	112.22612937679514, 108.91524361725897, 99.350027310661972, 
	16.902064719237387, 116.52611221047118, 118.44030319387093, 
	1.8005443713627756, 105.51905111595988, 10.464443478733301, 
	105.72949772095308, 70.603553343098611, 4.6445390335284173, 
	59.767248257063329, 115.36569624301046, 99.718200305011123, 
	96.584081499371678, 67.470765164587647, 106.02789150504395, 
	117.65104419644922, 120.4371798792854, 75.325613526627421, 
	10.272050822619349, 86.328772985842079, 22.265794642269611, 
	109.86511220689863, 47.378903591539711, 121.86315448442474, 
	50.738730230834335, 29.86259401217103, 123.6715569444932, 
	20.12369928508997, 89.050810230895877, 9.4124473645351827, 
	110.91702653188258, 50.259674362838268, 112.20425055501983, 
	14.098267829511315, 95.70136451581493, 106.60690627107397, 
	16.091330937575549, 56.603717565070838, 123.85576429218054, 
	13.681861021090299, 79.74437233665958, 2.6124773141928017, 
	92.783686938229948, 124.67039604252204, 10.88409340986982, 
	106.01856771204621, 97.532898479606956, 106.57870614249259, 
	3.7366205044090748, 67.274674311280251, 121.8603552589193, 
	108.17202668404207, 85.303708528168499, 98.969699303619564, 
	108.43108559260145, 55.16086700046435, 111.21830724459141, 
	27.87293240102008, 113.35955679602921, 63.842655413784087, 
	41.029215455055237, 15.900279967579991, 81.035312949214131, 
	108.59107061801478, 30.689855365548283, 89.412319208029658, 
	104.32100826594979, 73.73577278200537, 62.240019062999636, 
	122.7273592511192, 127.69526018900797, 53.266940758563578, 
	26.385443199425936, 31.852994742337614, 60.318720106035471, 
	106.75023480178788, 123.1608775104396, 67.136526592075825, 
	74.612110088579357, 50.014800885692239, 7.3641170430928469, 
	34.079227840993553, 22.432145269587636, 56.670952616259456, 
	51.80826749978587, 22.195442789234221, 30.981756458058953, 
	75.236678312532604, 9.5786990523338318, 123.50675575854257, 
	107.84753859229386, 26.502576827071607, 123.75724596064538, 
	59.773312723264098, 25.075215117074549, 8.0129718733951449, 
	75.072658884804696, 7.5858649895526469, 88.483324609696865, 
	62.445394677575678, 98.868400434497744, 34.609224846586585, 
	77.441016503609717, 94.043007473926991, 101.08413251955062, 
	124.31909865280613, 96.04773828946054, 82.360889608506113, 
	18.891335835680366, 68.46037698443979, 60.479840363375843, 
	67.249214683193713, 1.8475548955611885, 97.836682190652937, 
	122.86259609041736, 20.111821161117405, 76.971484495792538, 
	33.145381717011333, 43.719234322197735, 86.634274802636355, 
	84.64367246767506, 61.662859959993511, 70.248976637609303, 
	107.94150966824964, 9.0721677448600531, 13.673135004937649, 
	57.889076344668865, 88.426921632140875, 102.89679186278954, 
	122.23789864778519, 110.53688008151948, 93.966986203100532, 
	92.076594402547926, 27.435205929912627, 37.485007658600807, 
	109.78439133847132, 103.388507258147, 104.15006951801479, 
	121.72934733005241, 120.76649495400488, 99.527349165640771, 
	28.798621307592839, 48.62988393381238, 29.444443963933736, 
	97.544316857121885, 97.303895185235888, 78.383364802692086, 
	28.332693761680275, 64.851169708650559, 31.460166114382446, 
	94.253272936213762, 54.216616495978087, 103.43817389151081, 
	67.886691409628838, 61.006220073904842, 108.77033335529268, 
	107.87698537064716, 59.092851595487446, 57.969143963884562, 
	112.69650015281513, 125.05267392098904, 27.910256846807897, 
	11.642416686750948, 90.939782814122736, 45.338254536967725, 
	109.72203395236284, 16.452337529044598, 119.88565072463825, 
	79.953929136507213, 18.934011354111135, 19.302236509043723, 
	93.045928588602692, 41.733016965445131, 59.477046996355057, 
	94.16006256500259, 66.712428285740316, 70.038897995371372, 
	34.763222227338701, 6.9380326722748578, 59.907406228594482, 
	6.6968645481392741, 76.787452613469213, 58.724504555109888, 
	116.29605393577367, 86.348621093202382, 67.041910664644092, 
	33.243913532234728, 113.08473249897361, 83.9518963964656, 
	50.902247272897512, 49.836591531988233, 49.785904100630432, 
	4.0624160408042371, 59.907728772610426, 2.9345146864652634, 
	112.50538549013436, 63.047596833668649, 95.98052541539073, 
	30.548221048433334, 64.676462328992784, 35.60327540198341, 
	3.2184868971817195, 18.215725228190422, 93.682220642920583, 
	26.527585106436163, 99.641311642713845, 66.776509573217481, 
	94.776973059400916, 51.949432726483792, 58.044449002481997, 
	87.996135239023715, 103.49550795322284, 9.1604594085365534, 
	6.4134506094269454, 76.917759567964822, 50.933169982861727, 
	81.086652269586921, 78.237770894076675, 104.57264517294243, 
	35.713973348028958, 106.51287221210077, 111.55305506289005, 
	19.486252128146589, 28.542523724492639, 90.392913988791406, 
	105.26240702951327, 108.32411298854277, 122.32006587833166, 
	1.900063393637538, 56.434400526341051, 108.7762912530452, 
	64.264323640149087, 84.198362663853914, 115.90487617254257, 
	61.198874360881746, 115.97609204612672, 121.22355076530948, 
	30.060146544594318, 28.798388950526714, 10.580789789091796, 
	65.893074819818139, 31.833009195979685, 110.60343799134716, 
	8.0986612443812191, 3.6456328718923032, 21.536151939071715, 
	78.216087408363819, 96.394372925162315, 7.4307776181958616, 
	88.162504672538489, 23.735272297635674, 106.9431948964484, 
	51.052008883096278, 8.2300993502140045, 35.497167291585356, 
	36.840035066008568, 71.918207032140344, 9.5465767672285438, 
	26.514410655945539, 74.923283629585057, 119.80558476131409, 
	119.06185893714428, 118.85850019846112, 94.20657235942781, 
	90.793678595218807, 103.8247912703082, 84.981947926338762, 
	107.10667231539264, 52.06488355435431, 106.47066353680566, 
	127.79056827910244, 87.410060520283878, 57.615856547374278, 
	49.256717476528138, 98.481984601356089, 111.88392525631934, 
	90.868358179926872, 102.14387483522296, 56.013101504649967, 
	70.860478753689677, 3.7261798125691712, 96.49347253376618, 
	86.058997620362788, 18.674823581706733, 110.45522812893614, 
	46.838189892470837, 45.84736270736903, 53.604904909618199, 
	17.984899566043168, 119.51147867180407, 22.409610714763403, 
	31.344530477188528, 42.900306420400739, 106.08571967296302, 
	85.72173237381503, 69.538689414039254, 74.25811324082315, 
	7.9587333234958351, 85.125704918988049, 42.732920446898788, 
	105.65350128849968, 3.4852933674119413, 7.572783209849149, 
	1.6293824329040945, 40.280327862128615, 81.089571783784777, 
	17.1322060842067, 79.84219974745065, 106.98096791142598, 
	15.674030893947929, 89.798768336419016, 4.9515464697033167, 
	46.41052556456998, 75.937270705122501, 72.20791667047888, 
	90.773783176671714, 101.54822202585638, 95.53999622957781, 
	75.273653720039874, 39.987971813417971, 78.374638195149601, 
	73.607084757182747, 10.151776146143675, 127.12993296328932, 
	68.22310304408893, 90.020829128101468, 46.924328956287354, 
	4.9403550084680319, 112.23323167301714, 99.919972344767302, 
	82.608843398746103, 15.215564381331205, 20.396968877408653, 
	86.134836092591286, 74.460751311853528, 69.427891523111612, 
	101.64312560530379, 125.21133517939597, 78.160739174578339, 
	102.03863861085847, 91.572874325793236, 62.886631165631115, 
	88.28104078117758, 124.19953790213913, 47.304079293739051, 
	63.565674199722707, 110.08833324629813, 126.36571483081207, 
	66.721421373542398, 115.55380753241479, 95.336104530375451, 
	41.631134749390185, 12.820422243792564, 9.8095324616879225, 
	88.936884183436632, 39.278557303827256, 14.152523647993803, 
	54.676685379352421, 32.540594122838229, 41.9198366003111, 
	52.253170723095536, 103.38720667362213, 104.76547622634098, 
	52.902209120802581, 63.046359764412045, 76.231106647755951, 
	6.075936506036669, 63.996591053437442, 68.716641753446311, 
	23.302505458239466, 86.276771190576255, 123.98339603561908, 
	104.80975831439719, 8.1545471106655896, 66.004489412065595, 
	57.513177492655814, 6.4055330231785774, 121.82742046331987, 
	29.742494091391563, 70.17482131998986, 84.239852977916598, 
	56.553547718096524, 108.75535717653111, 21.586255491245538, 
	95.802963929250836, 89.3324133339338, 80.385567367542535, 
	73.94469679472968, 2.2613418470136821, 64.620563392993063, 
	13.214770566206425, 120.59811645094305, 112.87877164501697, 
	51.176443573087454, 91.807992177084088, 38.261226983275265, 
	110.11891567055136, 74.61393428966403, 35.157809175550938, 
	66.479859383776784, 52.404002275783569, 104.76833258010447, 
	59.61862442176789, 7.7243995368480682, 13.236612603534013, 
	70.044677293393761, 49.177383476402611, 23.774166173767298, 
	111.73661134950817, 43.404185994993895, 101.32801293488592, 
	124.99400278599933, 44.028677515685558, 35.33714713761583, 
	110.81632118159905, 52.04907239228487, 12.83269949676469, 
	84.27451155660674, 57.374981930013746, 23.296429105103016, 
	46.875313147436827, 37.285776998382062, 109.23717672750354, 
	121.88945010118186, 56.522361129987985, 111.71540050255135, 
	106.97861281968653, 4.5539058209396899, 7.5747934030368924, 
	72.112247655168176, 41.279151524882764, 99.756925043649971, 
	81.794931074138731, 91.569000899791718, 112.73338886257261, 
	60.91184998722747, 102.51552472868934, 15.251541463658214, 
	74.753272654023021, 114.06800881866366, 30.259589750319719, 
	63.520985472016037, 80.653930789791048, 82.853134238626808, 
	31.650747284293175, 19.569080473389477, 38.008373587392271, 
	123.8591841221787, 76.673401191364974, 73.833030211273581, 
	118.86042168317363, 48.145031321793795, 96.870499875862151, 
	67.528523016255349, 97.816512071527541, 64.173833011649549, 
	18.983323212713003, 100.66148648923263, 56.38826963538304, 
	77.177857962436974, 124.0922244801186, 47.958741453941911, 
	117.78981328895316, 82.253885779064149, 63.196024090982974, 
	102.14547560922801, 110.68913197517395, 51.206975551787764, 
	20.13991430727765, 121.18264113692567, 93.827585033141077, 
	76.760984015185386, 125.17565302317962, 87.219013394322246, 
	91.531667583156377, 82.462917720433325, 106.2987010339275, 
	58.164641830604523, 16.949706374667585, 84.825106670148671, 
	28.579223012086004, 123.9073228999041, 26.653621753212065, 
	125.34306519525126, 46.765706611331552, 109.67028876114637, 
	6.0192889296449721, 65.203772591426969, 35.70885327225551, 
	86.050833424553275, 67.4117102175951, 103.95022966712713, 
	119.03416379634291, 96.946273472625762, 4.8419269821606576, 
	40.486013010144234, 18.979430566541851, 110.72478745970875, 
	48.207682451233268, 126.16710424283519, 123.52224721526727, 
	14.536492428276688, 112.05245101545006, 46.1478112754412, 
	47.268193403724581, 84.305266844108701, 71.446274513844401, 
	127.62415939988568, 45.672099894378334, 104.23190941428766, 
	8.3533351155929267, 8.5989660448394716, 42.405761461239308, 
	44.323119573760778, 74.859891015570611, 121.19334972836077, 
	43.31347992317751, 68.015393213834614, 86.78873009653762, 
	5.6137824412435293, 127.02277342090383, 50.204687763936818, 
	17.314854410011321, 108.27879833383486, 100.80081604188308, 
	53.53342746431008, 91.133807824458927, 75.540389578323811, 
	116.48509985767305, 89.081820703111589, 14.043018062133342, 
	4.5370793016627431, 84.958107168786228, 97.215218290220946, 
	27.028158693574369, 86.199492447543889, 60.526595643721521, 
	101.28304495289922, 104.57364846579731, 11.916640723124146, 
	75.952226776629686, 39.546004130970687, 71.562157411128283, 
	43.458098393399268, 57.30590310273692, 68.217438475694507, 
	66.678635265212506, 39.758875848259777, 118.08292152639478, 
	126.47749726753682, 55.257680118549615, 99.708781002555043, 
	94.731066541746259, 72.071128615643829, 96.452631861437112, 
	56.997833293862641, 16.081848888657987, 80.914266804698855, 
	8.8807347370311618, 118.66675274865702, 126.39894271921366, 
	95.722731075715274, 16.864393482450396, 54.309792152605951, 
	1.7568814684636891, 49.853363643400371, 8.5705695748329163, 
	113.50561654241756, 65.635460913181305, 75.626774719450623, 
	123.10319819534197, 121.87661073217168, 54.48451384389773, 
	123.58858524635434, 24.629198247566819, 41.741277498658746, 
	98.80146994907409, 7.2318868297152221, 23.423305643722415, 
	124.61030433000997, 86.878359070047736, 43.310668869875371, 
	4.3746497663669288, 99.028860996477306, 124.79221531096846, 
	10.745748994406313, 104.13702765712515, 110.05223049363121, 
	18.314868777059019, 92.362476802431047, 93.092822609003633, 
	25.012198331300169, 84.278742359485477, 75.020786012522876, 
	112.06068469956517, 22.832379458472133, 25.181845897808671, 
	85.522897235117853, 1.4414876513183117, 97.95209037931636, 
	59.588973318226635, 43.177464341744781, 39.950869020540267, 
	24.973086350597441, 75.107367790769786, 5.5766812451183796, 
	96.805069095920771, 118.05704615125433, 15.807796828448772, 
	21.886923110112548, 109.03895024722442, 68.248912952374667, 
	112.43861042195931, 64.544909789226949, 58.437038531526923, 
	6.2943387827835977, 3.1839116453193128, 64.848130733706057, 
	104.44216665625572, 105.33919474156573, 83.255195940379053, 
	90.763933756388724, 97.233933945186436, 19.554570960346609, 
	117.39853410236537, 91.656395957339555, 66.455358043778688, 
	60.547145375981927, 97.822906001005322, 45.296213698107749, 
	42.66535137873143, 37.171961008571088, 14.104529642499983, 
	83.472290003672242, 38.700142088811845, 80.29359867842868, 
	20.836555565241724, 84.154159703757614, 39.717092382255942, 
	78.037606784142554, 66.561022730078548, 64.273198627401143, 
	121.12763413507491, 39.029513168148696, 107.32401417102665, 
	47.943311383482069, 107.8816796457395, 1.7632742743007839, 
	102.35621690377593, 64.919669387862086, 103.92418284807354, 
	7.939144067466259, 6.097014881670475, 98.069574464578182, 
	43.672605658415705, 76.44370283652097, 93.10445033852011, 
	119.15660763159394, 50.602636467665434, 71.490312298759818, 
	112.6646269611083, 122.59639674099162, 9.7024168004281819, 
	101.21953997481614, 89.578021908644587, 69.700624902267009, 
	107.69414502056316, 110.16764246718958, 5.5434311795979738, 
	120.86370660969988, 31.780507617164403, 98.370596858207136, 
	63.076896888203919, 109.84483699779958, 99.538263856433332, 
	28.709555869456381, 7.4020868726074696, 84.07446667086333, 
	94.466958997305483, 61.367887306958437, 15.723022455815226, 
	68.929464148823172, 58.658576830290258, 85.163864111527801, 
	82.912024306133389, 63.12157680420205, 44.757207164075226, 
	9.7332256678491831, 52.734322240110487, 6.2348521803505719, 
	71.943686944898218, 8.7115876046009362, 114.33903189841658, 
	1.5682977177202702, 66.358886867295951, 55.296287052333355, 
	82.870324817486107, 86.492600330151618, 94.927373252343386, 
	8.8380059343762696, 121.20886661484838, 46.79184781620279, 
	84.711086887400597, 117.10366559308022, 123.6823690882884, 
	98.274647405836731, 59.672629254404455, 1.2354587875306606, 
	120.18848010990769, 6.4091389044187963, 99.734471154399216, 
	110.07859435677528, 59.816529481671751, 32.157749338075519, 
	117.33822038210928, 65.888795936945826, 5.9734674538485706, 
	77.262249410152435, 110.40264801355079, 62.366291496902704, 
	127.85841086506844, 6.2249982063658535, 65.05058440938592, 
	3.6131852040998638, 62.87757172388956, 52.612359500490129, 
	49.526569426991045, 122.05007542436942, 36.209037665743381, 
	76.259744937065989, 24.717098647728562, 84.960403476376086, 
	72.866034144069999, 79.582048246171325, 87.848932099528611, 
	27.529080491047353, 78.354156295303255, 101.83271454134956, 
	27.593141198158264, 28.380562806501985, 99.836039224173874, 
	40.271735736634582, 76.794884727802128, 16.596009006723762, 
	79.151404023170471, 7.7159544308669865, 120.52306316699833, 
	104.49418163951486, 7.3184443609789014, 98.028348383493721)
)
, names = c("class", "x", "y")
, row.names = c("1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", "14",
	"15", "16", "17", "18", "19", "20", "21", "22", "23", "24", "25", "26",
	"27", "28", "29", "30", "31", "32", "33", "34", "35", "36", "37", "38",
	"39", "40", "41", "42", "43", "44", "45", "46", "47", "48", "49", "50",
	"51", "52", "53", "54", "55", "56", "57", "58", "59", "60", "61", "62",
	"63", "64", "65", "66", "67", "68", "69", "70", "71", "72", "73", "74",
	"75", "76", "77", "78", "79", "80", "81", "82", "83", "84", "85", "86",
	"87", "88", "89", "90", "91", "92", "93", "94", "95", "96", "97", "98",
	"99", "100", "101", "102", "103", "104", "105", "106", "107", "108",
	"109", "110", "111", "112", "113", "114", "115", "116", "117", "118",
	"119", "120", "121", "122", "123", "124", "125", "126", "127", "128",
	"129", "130", "131", "132", "133", "134", "135", "136", "137", "138",
	"139", "140", "141", "142", "143", "144", "145", "146", "147", "148",
	"149", "150", "151", "152", "153", "154", "155", "156", "157", "158",
	"159", "160", "161", "162", "163", "164", "165", "166", "167", "168",
	"169", "170", "171", "172", "173", "174", "175", "176", "177", "178",
	"179", "180", "181", "182", "183", "184", "185", "186", "187", "188",
	"189", "190", "191", "192", "193", "194", "195", "196", "197", "198",
	"199", "200", "201", "202", "203", "204", "205", "206", "207", "208",
	"209", "210", "211", "212", "213", "214", "215", "216", "217", "218",
	"219", "220", "221", "222", "223", "224", "225", "226", "227", "228",
	"229", "230", "231", "232", "233", "234", "235", "236", "237", "238",
	"239", "240", "241", "242", "243", "244", "245", "246", "247", "248",
	"249", "250", "251", "252", "253", "254", "255", "256", "257", "258",
	"259", "260", "261", "262", "263", "264", "265", "266", "267", "268",
	"269", "270", "271", "272", "273", "274", "275", "276", "277", "278",
	"279", "280", "281", "282", "283", "284", "285", "286", "287", "288",
	"289", "290", "291", "292", "293", "294", "295", "296", "297", "298",
	"299", "300", "301", "302", "303", "304", "305", "306", "307", "308",
	"309", "310", "311", "312", "313", "314", "315", "316", "317", "318",
	"319", "320", "321", "322", "323", "324", "325", "326", "327", "328",
	"329", "330", "331", "332", "333", "334", "335", "336", "337", "338",
	"339", "340", "341", "342", "343", "344", "345", "346", "347", "348",
	"349", "350", "351", "352", "353", "354", "355", "356", "357", "358",
	"359", "360", "361", "362", "363", "364", "365", "366", "367", "368",
	"369", "370", "371", "372", "373", "374", "375", "376", "377", "378",
	"379", "380", "381", "382", "383", "384", "385", "386", "387", "388",
	"389", "390", "391", "392", "393", "394", "395", "396", "397", "398",
	"399", "400", "401", "402", "403", "404", "405", "406", "407", "408",
	"409", "410", "411", "412", "413", "414", "415", "416", "417", "418",
	"419", "420", "421", "422", "423", "424", "425", "426", "427", "428",
	"429", "430", "431", "432", "433", "434", "435", "436", "437", "438",
	"439", "440", "441", "442", "443", "444", "445", "446", "447", "448",
	"449", "450", "451", "452", "453", "454", "455", "456", "457", "458",
	"459", "460", "461", "462", "463", "464", "465", "466", "467", "468",
	"469", "470", "471", "472", "473", "474", "475", "476", "477", "478",
	"479", "480", "481", "482", "483", "484", "485", "486", "487", "488",
	"489", "490", "491", "492", "493", "494", "495", "496", "497", "498",
	"499", "500", "501", "502", "503", "504", "505", "506", "507", "508",
	"509", "510", "511", "512", "513", "514", "515", "516", "517", "518",
	"519", "520", "521", "522", "523", "524", "525", "526", "527", "528",
	"529", "530", "531", "532", "533", "534", "535", "536", "537", "538",
	"539", "540", "541", "542", "543", "544", "545", "546", "547", "548",
	"549", "550", "551", "552", "553", "554", "555", "556", "557", "558",
	"559", "560", "561", "562", "563", "564", "565", "566", "567", "568",
	"569", "570", "571", "572", "573", "574", "575", "576", "577", "578",
	"579", "580", "581", "582", "583", "584", "585", "586", "587", "588",
	"589", "590", "591", "592", "593", "594", "595", "596", "597", "598",
	"599", "600", "601", "602", "603", "604", "605", "606", "607", "608",
	"609", "610", "611", "612", "613", "614", "615", "616", "617", "618",
	"619", "620", "621", "622", "623", "624", "625", "626", "627", "628",
	"629", "630", "631", "632", "633", "634", "635", "636", "637", "638",
	"639", "640", "641", "642", "643", "644", "645", "646", "647", "648",
	"649", "650", "651", "652", "653", "654", "655", "656", "657", "658",
	"659", "660", "661", "662", "663", "664", "665", "666", "667", "668",
	"669", "670", "671", "672", "673", "674", "675", "676", "677", "678",
	"679", "680", "681", "682", "683", "684", "685", "686", "687", "688",
	"689", "690", "691", "692", "693", "694", "695", "696", "697", "698",
	"699", "700", "701", "702", "703", "704", "705", "706", "707", "708",
	"709", "710", "711", "712", "713", "714", "715", "716", "717", "718",
	"719", "720", "721", "722", "723", "724", "725", "726", "727", "728",
	"729", "730", "731", "732", "733", "734", "735", "736", "737", "738",
	"739", "740", "741", "742", "743", "744", "745", "746", "747", "748",
	"749", "750", "751", "752", "753", "754", "755", "756", "757", "758",
	"759", "760", "761", "762", "763", "764", "765", "766", "767", "768",
	"769", "770", "771", "772", "773", "774", "775", "776", "777", "778",
	"779", "780", "781", "782", "783", "784", "785", "786", "787", "788",
	"789", "790", "791", "792", "793", "794", "795", "796", "797", "798",
	"799", "800", "801", "802", "803", "804", "805", "806", "807", "808",
	"809", "810", "811", "812", "813", "814", "815", "816", "817", "818",
	"819", "820", "821", "822", "823", "824", "825", "826", "827", "828",
	"829", "830", "831", "832", "833", "834", "835", "836", "837", "838",
	"839", "840", "841", "842", "843", "844", "845", "846", "847", "848",
	"849", "850", "851", "852", "853", "854", "855", "856", "857", "858",
	"859", "860", "861", "862", "863", "864", "865", "866", "867", "868",
	"869", "870", "871", "872", "873", "874", "875", "876", "877", "878",
	"879", "880", "881", "882", "883", "884", "885", "886", "887", "888",
	"889", "890", "891", "892", "893", "894", "895", "896", "897", "898",
	"899", "900", "901", "902", "903", "904", "905", "906", "907", "908",
	"909", "910", "911", "912", "913", "914", "915", "916", "917", "918",
	"919", "920", "921", "922", "923", "924", "925", "926", "927", "928",
	"929", "930", "931", "932", "933", "934", "935", "936", "937", "938",
	"939", "940", "941", "942", "943", "944", "945", "946", "947", "948",
	"949", "950", "951", "952", "953", "954", "955", "956", "957", "958",
	"959", "960", "961", "962", "963", "964", "965", "966", "967", "968",
	"969", "970", "971", "972", "973", "974", "975", "976", "977", "978",
	"979", "980", "981", "982", "983", "984", "985", "986", "987", "988",
	"989", "990", "991", "992", "993", "994", "995", "996", "997", "998",
	"999", "1000", "1001", "1002", "1003", "1004", "1005", "1006", "1007",
	"1008", "1009", "1010", "1011", "1012", "1013", "1014", "1015", "1016",
	"1017", "1018", "1019", "1020", "1021", "1022", "1023", "1024", "1025",
	"1026", "1027", "1028", "1029", "1030", "1031", "1032", "1033", "1034",
	"1035", "1036", "1037", "1038", "1039", "1040", "1041", "1042", "1043",
	"1044", "1045", "1046", "1047", "1048", "1049", "1050", "1051", "1052",
	"1053", "1054", "1055", "1056", "1057", "1058", "1059", "1060", "1061",
	"1062", "1063", "1064", "1065", "1066", "1067", "1068", "1069", "1070",
	"1071", "1072", "1073", "1074", "1075", "1076", "1077", "1078", "1079",
	"1080", "1081", "1082", "1083", "1084", "1085", "1086", "1087", "1088",
	"1089", "1090", "1091", "1092", "1093", "1094", "1095", "1096", "1097",
	"1098", "1099", "1100", "1101", "1102", "1103", "1104")
, class = "data.frame"
)
